/**
 * The App component
 */
import React, { useState, useRef, useCallback, useEffect } from 'react';
import axios from 'axios';

import {ProjectModel, Toast} from '@bryntum/schedulerpro';

import { BryntumScheduler, BryntumDemoHeader, BryntumThemeCombo, BryntumCombo } from '@bryntum/schedulerpro-react';
import './App.scss';

import { schedulerConfig, data } from './AppConfig.js';
const App = props => {
    const initialIndex = 0;
    const schedulerRef = useRef(null);

    const [index, setIndex] = useState(initialIndex);
    const [resources, setResources] = useState([]);
    const [events, setEvents] = useState([]);
    const [assign, setAssig] = useState([]);

    // Called when user selects "Load data with Axios"
    const loadData = useCallback(() => {
        axios
            .get('./data.json')
            .then(response => {
                const { rows : resources } = response.data.resources;
                const { rows : events } = response.data.events;
                const { rows : assignments } = response.data.assignments;

                (async () => {
                    await projects.schedule.loadInlineData({
                        eventsData: events,
                        resourcesData: resources,
                        assignmentsData: assignments,
                    });
                })();
                setAssig(assignments)
            })
            .catch(error => {
                console.log(error);
            });
    }, []);

    useEffect(() => {
        loadData()
    }, [loadData]);

    // Called when data changes in any of the Scheduler stores
    const onDataChange = useCallback(({ store, action, records }) => {
        if ('dataset' !== action && store.changes) {
            Toast.show(`
            <h3>${store.storeId} changed</h3>
            Added: <strong>${store.changes.added.length}</strong>
            Modified: <strong>${store.changes.modified.length}</strong>
            Removed: <strong>${store.changes.removed.length}</strong>
            `);
        }
    }, []);

    const [comboItems] = useState([
        { value : 0, text : 'Dataset 0' },
        { value : 1, text : 'Dataset 1' },
        { value : 2, text : 'Dataset 2 - empty' },
        { value : 3, text : 'Dataset 3' },
        { value : 4, text : 'Dataset 4' },
        { value : 5, text : 'Load data with Axios' }
    ]);

    // Configure Bryntum projects
    const storeConfig = React.useMemo(() => {
        return {
            resourceStore: {
                syncDataOnLoad: false,
                sorters: [{ field: 'name' }],
            },
            eventStore: {
                syncDataOnLoad: false,
                sorters: [{ field: 'name' }],
            },
            assignmentStore: {
                syncDataOnLoad: false,
                autoCommit: true,
            },
        };
    }, []);

    const projects = React.useMemo(
        () => ({
            schedule: new ProjectModel({
                ...(schedulerConfig.project || {}),
                ...storeConfig,
            }),
        }),
        [storeConfig]
    );


    return (
        <>
            {/* BryntumDemoHeader component is used for Bryntum example styling only and can be removed */}
            <BryntumDemoHeader
                children={<BryntumThemeCombo />}
            />
            <div className="demo-toolbar align-right">
                <BryntumCombo
                    label="Select Dataset"
                    value={index}
                    inputWidth="12em"
                    onChange={({ value }) => setIndex(value)}
                    editable={false}
                    items={comboItems}
                />
            </div>
            <BryntumScheduler
                ref={schedulerRef}
                {...schedulerConfig}
                onDataChange={onDataChange}
                project={projects.schedule}
            />
        </>
    );
};

export default App;
